Index: src/utils/SkDashPathPriv.h |
diff --git a/src/utils/SkDashPathPriv.h b/src/utils/SkDashPathPriv.h |
index 94222a271a6647bcb70762806298da846ef603b8..7453dcec82e35829b80db097d005746d0996782b 100644 |
--- a/src/utils/SkDashPathPriv.h |
+++ b/src/utils/SkDashPathPriv.h |
@@ -15,11 +15,11 @@ namespace SkDashPath { |
* Calculates the initialDashLength, initialDashIndex, and intervalLength based on the |
* inputed phase and intervals. If adjustedPhase is passed in, then the phase will be |
* adjusted to be between 0 and intervalLength. The result will be stored in adjustedPhase. |
* If adjustedPhase is NULL then it is assumed phase is already between 0 and intervalLength |
*/ |
void CalcDashParameters(SkScalar phase, const SkScalar intervals[], int32_t count, |
SkScalar* initialDashLength, int32_t* initialDashIndex, |
- SkScalar* intervalLength, SkScalar* adjustedPhase = NULL); |
+ SkScalar* intervalLength, SkScalar* adjustedPhase = nullptr); |
bool FilterDashPath(SkPath* dst, const SkPath& src, SkStrokeRec*, const SkRect*, |
const SkScalar aIntervals[], int32_t count, SkScalar initialDashLength, |
@@ -15,11 +15,11 @@ namespace SkDashPath { |
* inputed phase and intervals. If adjustedPhase is passed in, then the phase will be |
* adjusted to be between 0 and intervalLength. The result will be stored in adjustedPhase. |
- * If adjustedPhase is NULL then it is assumed phase is already between 0 and intervalLength |
+ * If adjustedPhase is nullptr then it is assumed phase is already between 0 and intervalLength |
*/ |
void CalcDashParameters(SkScalar phase, const SkScalar intervals[], int32_t count, |